## Healthcare_Puller

### This project aggregates several functions to pull down various healthcare regulations from various sources

### Current implementations
* CMS Federal Register Rules
    1. Rule and Prospective Rules (last 1000 but currently around 850 historically)
    2. Public inspection documents on a given date (defaults to the current date)